@@ -56,7 +56,7 @@
 #' heatmap(as.matrix(USArrests), Rowv = dend)
 #' }
 seriate_dendrogram <- function(dend, x, method = c("OLO", "GW"), ...) {
-  if (!requireNamespace("seriation")) stop("Please first install seriation:\n install.packages('seriaten') ")
+  if (!requireNamespace("seriation")) stop("Please first install seriation:\n install.packages('seriation')")
 
   if (!is.dendrogram(dend) & !is.hclust(dend)) stop("dend must be either a dendrogram or an hclust object")
   if (!is.dist(x)) stop("x must be a dist object")
